run_simulation: This function runs a simulation model multiple times and...

Description Usage

View source: R/run_simulation.R

Description

This function runs a simulation model multiple times and stores the statistics of interest in a dataframe. The input data and model specifications are generated by the function 'specify_simulation()'. In this function you define the number pf replicates, the sample size in each simulation run, and the distribution from which the x-values are randomly sampled.

Usage

1
run_simulation(df, reps = 1000, sample_size = "as data", xdistr = "as data")

mvb25/smesp documentation built on Dec. 21, 2021, 11:04 p.m.