specify_model: Specifies the model and sets the variables Specify the type...

Description Usage

View source: R/specify_model.R

Description

Specifies the model and sets the variables Specify the type of analysis, the predictor and response variables, variance structure, and whether to test a null hypothesis or generate a confidence interval. Currently, only two predictor variables are allowed in the case of a regression model and maximum one of the predictor variables can be a categorical variable. The categorical variable can only have two levels.

Usage

 1
 2
 3
 4
 5
 6
 7
 8
 9
10
11
12
13
14
15
16
specify_model(
  df,
  test,
  procedure,
  cont1 = NULL,
  cont2 = NULL,
  cat1 = NULL,
  cat2 = NULL,
  resp = NULL,
  error_cat = NULL,
  error_cont1 = 1,
  het_cont1 = 1,
  error_cont2 = 1,
  het_cont2 = 1,
  success
)

mvb25/smesp documentation built on Dec. 21, 2021, 11:04 p.m.