visualise_simulation: This function visualizes the result of a single simulation,...

Description Usage

View source: R/visualise_simulation.R

Description

This function visualizes the result of a single simulation, plotting the original data and the simulated data in one single graph. Data and the simulation settings are taken from the data frame + meta data that is generated by the function 'specify_simulation()'. In this function, a few choices need to be made with regard to the sampling procedure.

Usage

1
visualise_simulation(df, xdistr = "as data", sample_size = "as data")

mvb25/smesp documentation built on Dec. 21, 2021, 11:04 p.m.