View source: R/run_simulation.R
This function runs a simulation model multiple times and stores the statistics of interest in a dataframe. The input data and model specifications are generated by the function 'specify_simulation()'. In this function you define the number pf replicates, the sample size in each simulation run, and the distribution from which the x-values are randomly sampled.
1 | run_simulation(df, reps = 1000, sample_size = "as data", xdistr = "as data")
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.