View source: R/specify_model.R
Specifies the model and sets the variables Specify the type of analysis, the predictor and response variables, variance structure, and whether to test a null hypothesis or generate a confidence interval. Currently, only two predictor variables are allowed in the case of a regression model and maximum one of the predictor variables can be a categorical variable. The categorical variable can only have two levels.
1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.