View source: R/visualise_simulation.R
This function visualizes the result of a single simulation, plotting the original data and the simulated data in one single graph. Data and the simulation settings are taken from the data frame + meta data that is generated by the function 'specify_simulation()'. In this function, a few choices need to be made with regard to the sampling procedure.
1 | visualise_simulation(df, xdistr = "as data", sample_size = "as data")
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.